@@ -227,7 +227,7 @@ class PlotTestCase(test.TestCase):
                             "uuid": "w1.1",
                             "description": "Be or not to be",
                             "args": {},
-                            "context": {"key": "context"},
+                            "contexts": {"key": "context"},
                             "sla": {"key": "sla"},
                             "runner_type": "crunner",
                             "runner": {},
@@ -265,7 +265,7 @@ class PlotTestCase(test.TestCase):
                                 "uuid": "w2.1",
                                 "description": "Be or not to be",
                                 "args": {},
-                                "context": {"key": "context"},
+                                "contexts": {"key": "context"},
                                 "sla": {"key": "sla"},
                                 "runner_type": "crunner",
                                 "runner": {},
@@ -278,7 +278,7 @@ class PlotTestCase(test.TestCase):
                                 "uuid": "w2.2",
                                 "description": "Be or not to be3",
                                 "args": {},
-                                "context": {"key": "context"},
+                                "contexts": {"key": "context"},
                                 "sla": {"key": "sla"},
                                 "runner_type": "crunner",
                                 "runner": {},
@@ -389,7 +389,8 @@ class PlotTestCase(test.TestCase):
             trends.add_result.mock_calls)
         mock_get_template.assert_called_once_with("task/trends.html")
         template.render.assert_called_once_with(version="42.0",
-                                                data="[\"foo\", \"bar\"]")
+                                                data="[\"foo\", \"bar\"]",
+                                                include_libs=False)
 
 
 @ddt.ddt
@@ -474,7 +475,7 @@ class TrendsTestCase(test.TestCase):
             atomic = {"a": 123, "b": 456}
         return {
             "name": "Scenario.name_%d" % salt,
-            "args": {}, "context": {}, "runner_type": "foo", "runner": {},
+            "args": {}, "contexts": {}, "runner_type": "foo", "runner": {},
             "hooks": {},
             "pass_sla": sla_success,
             "sla": [{"success": sla_success}],
